.. image:: https://travis-ci.org/lazka/senf.svg?branch=master
    :target: https://travis-ci.org/lazka/senf

**Senf** makes filename handling easier by providing a set of filename
handling functions which work the same across all Python versions and
supported platforms.

For more info see https://senf.readthedocs.io/

.. image:: https://github.com/lazka/senf/raw/master/docs/images/ls.png
    :width: 699
    :height: 470

.. image:: https://github.com/lazka/senf/raw/master/docs/images/ansi.png
    :width: 699
    :height: 470
